@@ -1,9 +1,6 @@
 // Copyright (c) Microsoft Corporation.
 // Licensed under the MIT License.
 
-use std::env;
-use std::path::Path;
-
 fn main() -> Result<(), String> {
     built::write_built_file().expect("Failed to acquire build-time information");
 
